pub struct CompletionReady {
pub buffer_id: usize,
pub item_count: usize,
}Expand description
Event emitted when completion results are ready
The completion plugin emits this after the saturator has computed new completion items and updated the cache.
Fields
buffer_id: usizeBuffer ID the completions are for
item_count: usizeNumber of completion items available